@@ -454,23 +454,23 @@ GtkWidget *create_scrolled_window_with_text(const char *text,
 /*******************************************************************************/
 /* get icon set names */
 int create_icon_set_list(gchar *dir_path, GSList ** store, gchar *type){
-    Dirent	*dp;
-    DIR		*dir_fd;
-    gint	sets_number = 0,
-		t = DT_DIR;
+    Dirent  *dp;
+    DIR     *dir_fd;
+    gint    sets_number = 0,
+            t = DT_DIR;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     if(!strcmp(type, "dir"))
-	t = DT_DIR;
+        t = DT_DIR;
     if(!strcmp(type, "file"))
-	t = DT_REG;
+        t = DT_REG;
     dir_fd = opendir(dir_path);
     if(dir_fd){
         while((dp = readdir(dir_fd))){
             if(!strcmp(dp->d_name, ".") || !strcmp(dp->d_name, ".."))
                 continue;
-            if(dp->d_type == t){
+            if(dp->d_type == t || dp->d_type == DT_LNK){
                 *store = g_slist_append(*store, g_strdup(dp->d_name));
                 sets_number++;
             }
@@ -515,7 +515,7 @@ update_icons_set_base(const char *icon_set_name){
     int fd = -1;
 
     /* check current iconset directory */
-    if (!icon_set_name && (fd = open(app->config->icons_set_base, O_RDONLY)) != -1) {
+    if (!icon_set_name && app && app->config->icons_set_base && (fd = open(app->config->icons_set_base, O_RDONLY)) != -1) {
         close(fd);
         return;
     }
